Conversions
===========

Decibels
--------

.. python-apigen-group:: conversions-decibels

Ratios
------

.. python-apigen-group:: conversions-ratios

Signal-to-noise ratios
----------------------

.. python-apigen-group:: conversions-snrs
